@@ -35,7 +35,6 @@
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-graphic-effects.h>
-#include <eel/eel-gtk-macros.h>
 #include <eel/eel-string.h>
 #include <eel/eel-accessibility.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -308,7 +307,7 @@ nautilus_icon_canvas_item_set_property (GObject        *object,
 	switch (property_id) {
 
 	case PROP_EDITABLE_TEXT:
-		if (eel_strcmp (details->editable_text,
+		if (g_strcmp0 (details->editable_text,
 				g_value_get_string (value)) == 0) {
 			return;
 		}
@@ -329,8 +328,8 @@ nautilus_icon_canvas_item_set_property (GObject        *object,
 		break;
 
 	case PROP_ADDITIONAL_TEXT:
-		if (eel_strcmp (details->additional_text,
-				g_value_get_string (value)) == 0) {
+		if (g_strcmp0 (details->additional_text,
+			       g_value_get_string (value)) == 0) {
 			return;
 		}
 
