@@ -32,7 +32,6 @@
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 
-#include <eel/eel-gtk-macros.h>
 #include <eel/eel-string.h>
 
 G_DEFINE_TYPE (NautilusWindowSlot, nautilus_window_slot, G_TYPE_OBJECT);
@@ -353,14 +352,14 @@ nautilus_window_slot_set_title (NautilusWindowSlot *slot,
 
 	changed = FALSE;
 
-	if (eel_strcmp (title, slot->title) != 0) {
+	if (g_strcmp0 (title, slot->title) != 0) {
 		changed = TRUE;
 
 		g_free (slot->title);
 		slot->title = g_strdup (title);
 	}
 
-	if (eel_strlen (slot->title) > 0 && slot->current_location_bookmark) {
+	if (strlen (slot->title) > 0 && slot->current_location_bookmark) {
 		changed = TRUE;
 	}
 
@@ -406,8 +405,7 @@ nautilus_window_slot_update_icon (NautilusWindowSlot *slot)
 
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
-	info = EEL_CALL_METHOD_WITH_RETURN_VALUE (NAUTILUS_WINDOW_CLASS, window,
-						 get_icon, (window, slot));
+	info = NAUTILUS_WINDOW_CLASS (G_OBJECT_GET_CLASS (window))->get_icon (window, slot);
 
 	icon_name = NULL;
 	if (info) {
